{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "kerstenbreuer/trim_galore:0.4.4_1.14_0.11.7",
                    "class": "DockerRequirement"
                },
                {
                    "coresMin": 1,
                    "ramMin": 5000,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": "fastqc",
            "arguments": [
                {
                    "valueFrom": "$(runtime.outdir)",
                    "prefix": "-o"
                },
                {
                    "valueFrom": "--noextract"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#fastqc.cwl/bam"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#fastqc.cwl/fastq1"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#fastqc.cwl/fastq2"
                }
            ],
            "id": "#fastqc.cwl",
            "outputs": [
                {
                    "doc": "html report showing results from zip",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*_fastqc.html"
                    },
                    "id": "#fastqc.cwl/fastqc_html"
                },
                {
                    "doc": "all data e.g. figures",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*_fastqc.zip"
                    },
                    "id": "#fastqc.cwl/fastqc_zip"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "kerstenbreuer/samtools:1.7",
                    "class": "DockerRequirement"
                },
                {
                    "coresMin": 1,
                    "ramMin": 20000,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "bash",
                "-c"
            ],
            "arguments": [
                {
                    "valueFrom": "$(\"cp \" + inputs.bam_sorted.path + \" . && samtools index -b \" + inputs.bam_sorted.basename )"
                }
            ],
            "inputs": [
                {
                    "doc": "sorted bam input file",
                    "type": "File",
                    "id": "#samtools_index_hack.cwl/bam_sorted"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": ".bai",
                    "outputBinding": {
                        "glob": "$(inputs.bam_sorted.basename)"
                    },
                    "id": "#samtools_index_hack.cwl/bam_sorted_indexed"
                }
            ],
            "id": "#samtools_index_hack.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "kerstenbreuer/samtools:1.7",
                    "class": "DockerRequirement"
                },
                {
                    "coresMin": 1,
                    "ramMin": 20000,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "samtools",
                "merge"
            ],
            "inputs": [
                {
                    "id": "#samtools_merge.cwl/output_name",
                    "doc": "name of merged bam file",
                    "type": "string",
                    "inputBinding": {
                        "position": 1
                    }
                },
                {
                    "id": "#samtools_merge.cwl/bams",
                    "doc": "bam files to be merged",
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 2
                    }
                }
            ],
            "outputs": [
                {
                    "id": "#samtools_merge.cwl/bam_merged",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name)"
                    }
                }
            ],
            "id": "#samtools_merge.cwl"
        },
        {
            "doc": "Sort a bam file by read names.",
            "class": "CommandLineTool",
            "hints": [
                {
                    "dockerPull": "kerstenbreuer/samtools:1.7",
                    "class": "DockerRequirement"
                },
                {
                    "coresMin": 4,
                    "ramMin": 15000,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "samtools",
                "sort"
            ],
            "arguments": [
                {
                    "valueFrom": "$(runtime.cores)",
                    "prefix": "-@"
                }
            ],
            "inputs": [
                {
                    "doc": "aligned reads to be checked in sam or bam format",
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#samtools_sort.cwl/bam_unsorted"
                }
            ],
            "stdout": "$(inputs.bam_unsorted.basename)",
            "outputs": [
                {
                    "type": "File",
                    "id": "#samtools_sort.cwl/bam_sorted",
                    "outputBinding": {
                        "glob": "$(inputs.bam_unsorted.basename)"
                    }
                }
            ],
            "id": "#samtools_sort.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "kerstenbreuer/samtools:1.7",
                    "class": "DockerRequirement"
                },
                {
                    "coresMin": 1,
                    "ramMin": 10000,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "samtools",
                "view"
            ],
            "inputs": [
                {
                    "doc": "aligned reads to be checked in bam format",
                    "type": "File",
                    "inputBinding": {
                        "position": 10
                    },
                    "id": "#samtools_view_filter.cwl/bam"
                },
                {
                    "doc": "if paired end, only properly paired reads pass",
                    "type": "boolean",
                    "default": true,
                    "id": "#samtools_view_filter.cwl/is_paired_end"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "-h",
                    "position": 1
                },
                {
                    "valueFrom": "-b",
                    "position": 1
                },
                {
                    "valueFrom": "4",
                    "prefix": "-F",
                    "position": 1
                },
                {
                    "valueFrom": "20",
                    "prefix": "-q",
                    "position": 1
                },
                {
                    "valueFrom": "${\n  if ( inputs.is_paired_end ){\n     return \"-f\";\n  }\n  else {\n    return null;\n  }\n}\n",
                    "position": 2
                },
                {
                    "valueFrom": "${\n  if ( inputs.is_paired_end ){\n     return \"3\";\n  }\n  else {\n    return null;\n  }\n}\n",
                    "position": 3
                }
            ],
            "stdout": "$(inputs.bam.nameroot)_filt.bam",
            "outputs": [
                {
                    "type": "File",
                    "id": "#samtools_view_filter.cwl/bam_filtered",
                    "outputBinding": {
                        "glob": "$(inputs.bam.nameroot)_filt.bam"
                    }
                }
            ],
            "id": "#samtools_view_filter.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/bams"
                },
                {
                    "type": "boolean",
                    "id": "#main/is_paired_end"
                },
                {
                    "type": "string",
                    "id": "#main/sample_id"
                }
            ],
            "steps": [
                {
                    "doc": "samtools view",
                    "run": "#samtools_view_filter.cwl",
                    "in": [
                        {
                            "source": "#main/sorting_merged_bam/bam_sorted",
                            "id": "#main/filter_by_mapq/bam"
                        },
                        {
                            "source": "#main/is_paired_end",
                            "id": "#main/filter_by_mapq/is_paired_end"
                        }
                    ],
                    "out": [
                        "#main/filter_by_mapq/bam_filtered"
                    ],
                    "id": "#main/filter_by_mapq"
                },
                {
                    "doc": "samtools index - indexes sorted bam\n",
                    "run": "#samtools_index_hack.cwl",
                    "in": [
                        {
                            "source": "#main/sorting_filtered_bam/bam_sorted",
                            "id": "#main/indexing_filtered_bam/bam_sorted"
                        }
                    ],
                    "out": [
                        "#main/indexing_filtered_bam/bam_sorted_indexed"
                    ],
                    "id": "#main/indexing_filtered_bam"
                },
                {
                    "doc": "samtools merge - merging bam files of lane replicates",
                    "run": "#samtools_merge.cwl",
                    "in": [
                        {
                            "source": "#main/bams",
                            "id": "#main/lane_replicate_merging/bams"
                        },
                        {
                            "source": "#main/sample_id",
                            "valueFrom": "$(self + \".bam\")",
                            "id": "#main/lane_replicate_merging/output_name"
                        }
                    ],
                    "out": [
                        "#main/lane_replicate_merging/bam_merged"
                    ],
                    "id": "#main/lane_replicate_merging"
                },
                {
                    "doc": "fastqc - quality control for reads directly after mapping",
                    "run": "#fastqc.cwl",
                    "in": [
                        {
                            "source": "#main/indexing_filtered_bam/bam_sorted_indexed",
                            "id": "#main/qc/bam"
                        }
                    ],
                    "out": [
                        "#main/qc/fastqc_zip",
                        "#main/qc/fastqc_html"
                    ],
                    "id": "#main/qc"
                },
                {
                    "doc": "samtools sort - sorting of filtered bam",
                    "run": "#samtools_sort.cwl",
                    "in": [
                        {
                            "source": "#main/filter_by_mapq/bam_filtered",
                            "id": "#main/sorting_filtered_bam/bam_unsorted"
                        }
                    ],
                    "out": [
                        "#main/sorting_filtered_bam/bam_sorted"
                    ],
                    "id": "#main/sorting_filtered_bam"
                },
                {
                    "doc": "samtools sort - sorting of merged bam",
                    "run": "#samtools_sort.cwl",
                    "in": [
                        {
                            "source": "#main/lane_replicate_merging/bam_merged",
                            "id": "#main/sorting_merged_bam/bam_unsorted"
                        }
                    ],
                    "out": [
                        "#main/sorting_merged_bam/bam_sorted"
                    ],
                    "id": "#main/sorting_merged_bam"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "secondaryFiles": ".bai",
                    "outputSource": "#main/indexing_filtered_bam/bam_sorted_indexed",
                    "id": "#main/bam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/qc/fastqc_html",
                    "id": "#main/fastqc_html"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/qc/fastqc_zip",
                    "id": "#main/fastqc_zip"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
